==> qucs_0.0.5.orig.tar.gz: qucs-0.0.5.orig/qucs/components/phaseshifter.cpp <==
/***************************************************************************
                          phaseshifter.cpp  -  description
                             -------------------
    begin                : Sat Aug 23 2003
    copyright            : (C) 2003 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "phaseshifter.h"


Phaseshifter::Phaseshifter()
{
  Description = QObject::tr("phase shifter");

  Lines.append(new Line(-14,-14, 14,-14,QPen(QPen::darkBlue,2)));
  Lines.append(new Line(-14, 14, 14, 14,QPen(QPen::darkBlue,2)));
  Lines.append(new Line(-14,-14,-14, 14,QPen(QPen::darkBlue,2)));
  Lines.append(new Line( 14,-14, 14, 14,QPen(QPen::darkBlue,2)));
  Arcs.append(new Arc( -9, -9, 18, 18, 0, 16*360,QPen(QPen::darkBlue,2)));
  Lines.append(new Line(-10, 10, 10,-10,QPen(QPen::darkBlue,2)));

  Lines.append(new Line(-30,  0,-14,  0,QPen(QPen::darkBlue,2)));
  Lines.append(new Line( 14,  0, 30,  0,QPen(QPen::darkBlue,2)));

  Ports.append(new Port(-30,  0));
  Ports.append(new Port( 30,  0));

  x1 = -30; y1 = -17;
  x2 =  30; y2 =  17;

  tx = x1+4;
  ty = y2+4;
  Model = "PShift";
  Name  = "X";

  Props.append(new Property("phi", "90", true,
		QObject::tr("phase shift in degree")));
  Props.append(new Property("Zref", "50 Ohm", false,
		QObject::tr("reference impedance")));
}

Phaseshifter::~Phaseshifter()
{
}

Component* Phaseshifter::newOne()
{
  return new Phaseshifter();
}

Component* Phaseshifter::info(QString& Name, char* &BitmapFile, bool getNewOne)
{
  Name = QObject::tr("Phase Shifter");
  BitmapFile = "pshifter";

  if(getNewOne)  return new Phaseshifter();
  return 0;
}

==> qucs_0.0.7.orig.tar.gz: qucs-0.0.7.orig/qucs/components/phaseshifter.cpp <==
/***************************************************************************
                          phaseshifter.cpp  -  description
                             -------------------
    begin                : Sat Aug 23 2003
    copyright            : (C) 2003 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "phaseshifter.h"


Phaseshifter::Phaseshifter()
{
  Description = QObject::tr("phase shifter");

  Lines.append(new Line(-14,-14, 14,-14,QPen(QPen::darkBlue,2)));
  Lines.append(new Line(-14, 14, 14, 14,QPen(QPen::darkBlue,2)));
  Lines.append(new Line(-14,-14,-14, 14,QPen(QPen::darkBlue,2)));
  Lines.append(new Line( 14,-14, 14, 14,QPen(QPen::darkBlue,2)));
  Arcs.append(new Arc( -9, -9, 18, 18, 0, 16*360,QPen(QPen::darkBlue,2)));
  Lines.append(new Line(-10, 10, 10,-10,QPen(QPen::darkBlue,2)));

  Lines.append(new Line(-30,  0,-14,  0,QPen(QPen::darkBlue,2)));
  Lines.append(new Line( 14,  0, 30,  0,QPen(QPen::darkBlue,2)));

  Ports.append(new Port(-30,  0));
  Ports.append(new Port( 30,  0));

  x1 = -30; y1 = -17;
  x2 =  30; y2 =  17;

  tx = x1+4;
  ty = y2+4;
  Model = "PShift";
  Name  = "X";

  Props.append(new Property("phi", "90", true,
		QObject::tr("phase shift in degree")));
  Props.append(new Property("Zref", "50 Ohm", false,
		QObject::tr("reference impedance")));
}

Phaseshifter::~Phaseshifter()
{
}

Component* Phaseshifter::newOne()
{
  return new Phaseshifter();
}

Element* Phaseshifter::info(QString& Name, char* &BitmapFile, bool getNewOne)
{
  Name = QObject::tr("Phase Shifter");
  BitmapFile = "pshifter";

  if(getNewOne)  return new Phaseshifter();
  return 0;
}
